import smtplib
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
class exbo(object):
  # constructor
  def __init__(self):
    pass


def abhinav():
    print("Abhinav Jain")

def adrija():
    print("Adrija Sengupta")

def akarsh():
    print("Akarsh Shrivastava")

def armaan():
    print("Armaan Mittal")

def dev():
    print("Dev Goyal")

def dinesh():
    print("Dinesh Agrawal")

def gopal():
    print("Gopal Agarwal")

def gurman():
    print("Gurman Kaur")

def hushraj():
    print("Hushraj Singh")

def jahanvi():
    print("Jahanvi Srivastava")

def jasdeep():
    print("Jasdeep Singh")

def kanishk():
    print("Kanishk Jagya")

def pancham():
    print("Pancham Agarwal")

def pariansh():
    print("Pariansh Mahajan")

def reyan():
    print("Reyan Singh")

def saaransh():
    print("Saaransh Gupta")

def sharath():
    print("Sharath Chandra Chinnarigari")

def shaurya():
    print("Shaurya Verma")

def sparsh():
    print("Sparsh Rastogi")

def swapnil():
    print("Swapnil Chhibber")

def test():
    print("This is a test")
    
    

def sendEmail(email,password,recp_email,Subject, messageBody):
    try:
        sender_email = email
        sender_password = password
        recipient_email =recp_email
        message = MIMEMultipart()
        message['From'] = sender_email
        message['To'] = recipient_email
        message['Subject'] = Subject
        body = messageBody
        message.attach(MIMEText(body, 'plain'))

        with smtplib.SMTP('smtp.gmail.com', 587) as server:   
            server.starttls()
            server.login(sender_email, sender_password)     
            server.send_message(message)

        print(f"Email sent successfully to {recipient_email}")
    except:
        print(f"Error occurred. Email not sent for {recipient_email}")

if __name__ == '__main__':
  pass


#!/usr/bin/env python

import os
from setuptools import setup, find_packages
from ccstiet import __version__


# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

# the setup
setup(
    name='ccstiet',
    version=__version__,
    description='pip package for Creative Computing Society,Thapar University,Patiala,India',
    # long_description=read('README'),
    url='https://github.com/dgbkn/ccstiet_pip_package',
    author='dgbkn',
    author_email='anandrambkn@gmail.com',
    license='MIT',
    keywords='cctiet,creative,computing,society',
    packages=find_packages(exclude=('docs', 'tests', 'env', 'index.py')),
    include_package_data=True,
    install_requires=[
    ],
    extras_require={
    'dev': [],
    'docs': [],
    'testing': [],
    },
    classifiers=[],
    )
